//+------------------------------------------------------------------+
//|                                                      Line_Ix.mq4 |
//|                      Copyright  2005, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
#property copyright "Copyright  2005, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net/"

#property indicator_chart_window

//---- indicator parameters
extern int Period_ind = 15;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//----
   ObjectCreate("TL1", OBJ_TREND, 0, iTime( NULL, 0, 0), 0, iTime( NULL, 0, 1), 0);
   ObjectSet("TL1",OBJPROP_COLOR, Red);
   ObjectSet("TL1",OBJPROP_WIDTH, 0);
   ObjectSet("TL1",OBJPROP_STYLE, STYLE_DASHDOTDOT);

   ObjectCreate("TL2", OBJ_TREND, 0, iTime( NULL, 0, 0), 0, iTime( NULL, 0, 1), 0);
   ObjectSet("TL2",OBJPROP_COLOR, Lime);
   ObjectSet("TL2",OBJPROP_WIDTH, 0);
   ObjectSet("TL2",OBJPROP_STYLE, STYLE_DASHDOTDOT);

   return(0);
  }

//+------------------------------------------------------------------+
//| Bollinger Bands                                                  |
//+------------------------------------------------------------------+
int start()
{
   int k_H_min = 0;
   int g_H_min = 0;
   double Ix_H_min = 10000000.0;
   int k_L_min = 0;
   int g_L_min = 0;
   double Ix_L_min = 10000000.0;
   
   for (int k = Period_ind - 1; k >= 1; k--)
   {
      for (int g = k - 1; g >= 0; g--)
      {
         int High_koll = 0;
         double Ix_H = 0.0;
         int Low_koll = 0;
         double Ix_L = 0.0;
         for (int f = Period_ind - 1; f >= 0; f--)
         {
            double H = iHigh (NULL, 0, f) - (iHigh (NULL, 0, k) + ((iHigh (NULL, 0, g) - iHigh (NULL, 0, k))/(k - g))*(k - f));
            if (H <= 0.0) High_koll++;
            Ix_H = Ix_H + H;
            double L = iLow (NULL, 0, f)  - (iLow (NULL, 0, k)  + ((iLow (NULL, 0, g)  - iLow (NULL, 0, k)) /(k - g))*(k - f));
            if (L >= 0.0) Low_koll++;
            Ix_L = Ix_L + L;
         }
         if (High_koll == Period_ind)
         {
            Ix_H = MathAbs(Ix_H);
            if (Ix_H < Ix_H_min)
            {
               Ix_H_min = Ix_H;
               k_H_min = k;
               g_H_min = g;
            }
         }
         if (Low_koll == Period_ind)
         {
            Ix_L = MathAbs(Ix_L);
            if (Ix_L < Ix_L_min)
            {
               Ix_L_min = Ix_L;
               k_L_min = k;
               g_L_min = g;
            }
         }
      }
   }

   double h1 = iHigh( NULL, 0, k_H_min) - ((iHigh (NULL, 0, g_H_min) - iHigh (NULL, 0, k_H_min))/(k_H_min - g_H_min))*(Period_ind - 1 - k_H_min);
   double h2 = iHigh( NULL, 0, k_H_min) + ((iHigh (NULL, 0, g_H_min) - iHigh (NULL, 0, k_H_min))/(k_H_min - g_H_min))*k_H_min;
   ObjectSet("TL1", OBJPROP_TIME1,  iTime( NULL, 0, Period_ind - 1));
   ObjectSet("TL1", OBJPROP_PRICE1, h1);
   ObjectSet("TL1", OBJPROP_TIME2,  iTime( NULL, 0, 0));
   ObjectSet("TL1", OBJPROP_PRICE2, h2);

   double h3 = iLow( NULL, 0, k_L_min) - ((iLow (NULL, 0, g_L_min) - iLow (NULL, 0, k_L_min))/(k_L_min - g_L_min))*(Period_ind - 1 - k_L_min);
   double h4 = iLow( NULL, 0, k_L_min) + ((iLow (NULL, 0, g_L_min) - iLow (NULL, 0, k_L_min))/(k_L_min - g_L_min))*k_L_min;
   ObjectSet("TL2", OBJPROP_TIME1,  iTime( NULL, 0, Period_ind - 1));
   ObjectSet("TL2", OBJPROP_PRICE1, h3);
   ObjectSet("TL2", OBJPROP_TIME2,  iTime( NULL, 0, 0));
   ObjectSet("TL2", OBJPROP_PRICE2, h4);

   return(0);
}

int deinit()
{
   return(0);
}